@@ -1,5 +1,5 @@
 #
-# Copyright 2010-2015 Universidad Complutense de Madrid
+# Copyright 2010-2020 Universidad Complutense de Madrid
 #
 # This file is part of Numina
 #
@@ -7,7 +7,6 @@
 # License-Filename: LICENSE.txt
 #
 
-import warnings
 
 try:
     from functools import singledispatch
@@ -23,10 +22,20 @@ from numina.types.array import dump_numpy_array
 
 @singledispatch
 def dump(tag, obj, where):
+    """
+
+    Parameters
+    ----------
+    tag
+    obj
+    where
+
+    Returns
+    -------
+
+    """
 
     if hasattr(tag, '__numina_dump__'):
-        msg = "Usage of '__numina_dump__' is deprecated, use '_datatype_dump' instead"
-        warnings.warn(msg, DeprecationWarning)
         return tag.__numina_dump__(obj, where)
 
     if hasattr(tag, '_datatype_dump'):
@@ -43,7 +52,7 @@ def _(tag, obj, where):
     return [dump(tag, o, where) for o in obj]
 
 
-dump.register(numpy.ndarray, dump_numpy_array)
+dump.register(numpy.ndarray, lambda t, o, w: dump_numpy_array(o, w))
 
 
-dump.register(DataFrame, dump_dataframe)
\ No newline at end of file
+dump.register(DataFrame, lambda t,o,w: dump_dataframe(o, w))
